@@ -13,14 +13,16 @@ import numpy as np
 from multipledispatch import dispatch
 from numpy import allclose, array_equal
 
-from xpypact.utils.io import print_cols
+from xpypact.utils.xpypact_io import print_cols
 
 FISPACT_709_BINS_NUMBER = 709
 
 if TYPE_CHECKING:
     from collections.abc import Callable
 
-    from xpypact.types import NDArrayFloat
+    from _typeshed import SupportsWrite
+
+    from xpypact.xpypact_types import NDArrayFloat
 
 # pylint: disable=function-redefined
 
@@ -191,7 +193,7 @@ class Fluxes:
         Returns:
             float: flux total
         """
-        return cast(float, np.sum(self.fluxes))
+        return cast("float", np.sum(self.fluxes))
 
     def __hash__(self) -> int:
         """Use available information for hash.
@@ -282,7 +284,7 @@ def are_fluxes_close(
         b: the second flux to compare
         rtol: relative tolerance
         atol: absolute tolerance
-        equal_nan: see :func:`numpy.allclose()`
+        equal_nan: see :meth:`numpy.allclose()`
 
     Returns:
         bool: True, if the fluxes are equivalent by data
@@ -411,7 +413,7 @@ class FluxesDataSizeError(ValueError):
         Returns:
             an exception class __doc__
         """
-        return cast(str, self.__class__.__doc__)
+        return cast("str", self.__class__.__doc__)
 
 
 class ArbitraryFluxesDataSizeError(FluxesDataSizeError):
@@ -462,7 +464,7 @@ def define_709_bins_and_fluxes(data: NDArrayFloat) -> tuple[NDArrayFloat, NDArra
     return FISPACT_709_BINS, data[::-1]
 
 
-def _print_bin_values(fluxes: Fluxes, fid: TextIO, max_columns: int = 5) -> None:
+def _print_bin_values(fluxes: Fluxes, fid: SupportsWrite[str], max_columns: int = 5) -> None:
     """Print fluxes bins for FISPACT.
 
     Args:
@@ -482,7 +484,7 @@ class NotA709Error(FluxesDataSizeError):
     """Expected 709-group fluxes."""
 
 
-def print_709_fluxes(fluxes: Fluxes, fid: TextIO, max_columns: int = 7) -> None:
+def print_709_fluxes(fluxes: Fluxes, fid: SupportsWrite[str], max_columns: int = 7) -> None:
     """Print standard 709-group fluxes.
 
     Args:
@@ -498,7 +500,7 @@ def print_709_fluxes(fluxes: Fluxes, fid: TextIO, max_columns: int = 7) -> None:
     _print_bin_values(fluxes, fid, max_columns)
 
 
-def print_arbitrary_fluxes(fluxes: Fluxes, fid: TextIO, max_columns: int = 5) -> None:
+def print_arbitrary_fluxes(fluxes: Fluxes, fid: SupportsWrite[str], max_columns: int = 5) -> None:
     """Print fluxes in FISPACT arbitrary flux format.
 
     Args:
