@@ -2,6 +2,6 @@
 
 from __future__ import annotations
 
-from .io import print_cols
+from .xpypact_io import print_cols
 
 __all__ = ["print_cols"]
